@@ -84,10 +84,6 @@ def test_negative_IPv6_REGEX(addr):
     assert test_result is None  # The regex *should* fail on these addrs
 
 
-@pytest.mark.xfail(
-    sys.version_info[0] == 3 and sys.version_info[1] == 2,
-    reason="Known failure in Python3.2",
-)
 def testL4Object_asa_eq01():
     pp = L4Object(protocol="tcp", port_spec="eq smtp", syntax="asa")
     assert pp.protocol == "tcp"
@@ -100,20 +96,12 @@ def testL4Object_asa_eq02():
     assert pp.port_list == [25]
 
 
-@pytest.mark.xfail(
-    sys.version_info[0] == 3 and sys.version_info[1] == 2,
-    reason="Known failure in Python3.2 due to range()",
-)
 def testL4Object_asa_range01():
     pp = L4Object(protocol="tcp", port_spec="range smtp 32", syntax="asa")
     assert pp.protocol == "tcp"
     assert pp.port_list == range(25, 33)
 
 
-@pytest.mark.xfail(
-    sys.version_info[0] == 3 and sys.version_info[1] == 2,
-    reason="Known failure in Python3.2 due to range()",
-)
 def testL4Object_asa_lt01():
     pp = L4Object(protocol="tcp", port_spec="lt echo", syntax="asa")
     assert pp.protocol == "tcp"
@@ -181,14 +169,128 @@ def testIPv4Obj_attributes():
         ("is_reserved", False),
         ("is_multicast", False),
         ("is_private", False),
+        ("as_cidr_addr", "1.0.0.1/24"),
+        ("as_cidr_net", "1.0.0.0/24"),
         ("as_decimal", 16777217),
+        ("as_decimal_network", 16777216),
         ("as_hex_tuple", ("01", "00", "00", "01")),
         ("as_binary_tuple", ("00000001", "00000000", "00000000", "00000001")),
+        ("as_zeropadded", "001.000.000.001"),
+        ("as_zeropadded_network", "001.000.000.000/24"),
     ]
     for attribute, result_correct in results_correct:
+
         assert getattr(test_object, attribute) == result_correct
 
 
+def testIPv6Obj_attributes():
+    ## Ensure that attributes are accessible and pass the smell test
+    test_object = IPv6Obj("2001::dead:beef/64")
+    results_correct = [
+        ("ip", IPv6Address("2001::dead:beef")),
+        ("ip_object", IPv6Address("2001::dead:beef")),
+        ("netmask", IPv6Address("ffff:ffff:ffff:ffff::")),
+        ("prefixlen", 64),
+        ("network", IPv6Network("2001::/64")),
+        ("network_object", IPv6Network("2001::/64")),
+        ("hostmask", IPv6Address("::ffff:ffff:ffff:ffff")),
+        ("numhosts", 18446744073709551616),
+        ("version", 6),
+        ("is_reserved", False),
+        ("is_multicast", False),
+        # ("is_private", False),  # FIXME: disabling this for now...
+        # py2.7 and py3.x produce different results
+        ("as_cidr_addr", "2001::dead:beef/64"),
+        ("as_cidr_net", "2001::/64"),
+        ("as_decimal", 42540488161975842760550356429036175087),
+        ("as_decimal_network", 42540488161975842760550356425300246528),
+        (
+            "as_hex_tuple",
+            ("2001", "0000", "0000", "0000", "0000", "0000", "dead", "beef"),
+        ),
+        (
+            "as_binary_tuple",
+            (
+                "0010000000000001",
+                "0000000000000000",
+                "0000000000000000",
+                "0000000000000000",
+                "0000000000000000",
+                "0000000000000000",
+                "1101111010101101",
+                "1011111011101111",
+            ),
+        ),
+    ]
+    for attribute, result_correct in results_correct:
+
+        assert getattr(test_object, attribute) == result_correct
+
+
+def testIPv4Obj_sort_01():
+    """Simple IPv4Obj sorting test"""
+    cidr_addrs_list = [
+        "192.168.1.3/32",
+        "192.168.1.2/32",
+        "192.168.1.1/32",
+        "192.168.1.4/15",
+    ]
+
+    result_correct = [
+        "192.168.1.4/15",  # Shorter prefixes are "lower" than longer prefixes
+        "192.168.1.1/32",
+        "192.168.1.2/32",
+        "192.168.1.3/32",
+    ]
+
+    obj_list = [IPv4Obj(ii) for ii in cidr_addrs_list]
+    # Ensure we get the correct sorted order for this list
+    assert [ii.as_cidr_addr for ii in sorted(obj_list)] == result_correct
+
+
+def testIPv4Obj_sort_02():
+    """Complex IPv4Obj sorting test"""
+    cidr_addrs_list = [
+        "192.168.1.1/32",
+        "192.168.0.1/32",
+        "192.168.0.2/16",
+        "192.168.0.3/15",
+        "0.0.0.0/32",
+        "0.0.0.1/31",
+        "16.0.0.1/8",
+        "0.0.0.2/30",
+        "127.0.0.0/0",
+        "16.0.0.0/1",
+        "128.0.0.0/1",
+        "16.0.0.0/4",
+        "16.0.0.3/4",
+        "0.0.0.0/0",
+        "0.0.0.0/8",
+    ]
+
+    result_correct = [
+        "0.0.0.0/0",
+        "127.0.0.0/0",
+        "16.0.0.0/1",
+        "0.0.0.0/8",  # for the same network, longer prefixlens sort "higher" than shorter prefixlens
+        "0.0.0.2/30",  # for the same network, longer prefixlens sort "higher" than shorter prefixlens
+        "0.0.0.1/31",  # for the same network, longer prefixlens sort "higher" than shorter prefixlens
+        "0.0.0.0/32",
+        "16.0.0.0/4",
+        "16.0.0.3/4",
+        "16.0.0.1/8",  # for the same network, longer prefixlens sort "higher" than shorter prefixlens
+        "128.0.0.0/1",
+        "192.168.0.3/15",
+        "192.168.0.2/16",
+        "192.168.0.1/32",
+        "192.168.1.1/32",
+    ]
+
+    obj_list = [IPv4Obj(ii) for ii in cidr_addrs_list]
+    # Ensure we get the correct sorted order for this list
+    assert [ii.as_cidr_addr for ii in sorted(obj_list)] == result_correct
+
+
 def testIPv4Obj_recursive():
     """IPv4Obj() should be able to parse itself"""
     obj = IPv4Obj(IPv4Obj("1.1.1.1/24"))
@@ -196,12 +298,109 @@ def testIPv4Obj_recursive():
     assert obj.prefixlen == 24
 
 
+def testIPv4Obj_neq_01():
+    """Simple in-equality test fail (ref - Github issue #180)"""
+    assert IPv4Obj("1.1.1.1/24") != ""
+
+def testIPv4Obj_neq_02():
+    """Simple in-equality test"""
+    obj1 = IPv4Obj("1.1.1.1/24")
+    obj2 = IPv4Obj("1.1.1.2/24")
+    assert obj1 != obj2
+
+def testIPv4Obj_eq_01():
+    """Simple equality test"""
+    obj1 = IPv4Obj("1.1.1.1/24")
+    obj2 = IPv4Obj("1.1.1.1/24")
+    assert obj1 == obj2
+
+def testIPv4Obj_eq_02():
+    """Simple equality test"""
+    obj1 = IPv4Obj("1.1.1.1/24")
+    obj2 = IPv4Obj("1.1.1.0/24")
+    assert obj1 != obj2
+
+
+def testIPv4Obj_gt_01():
+    """Simple greater-than test - same network number"""
+    obj1 = IPv4Obj("1.1.1.1/24")
+    obj2 = IPv4Obj("1.1.1.0/24")
+    assert obj1 > obj2
+
+
+def testIPv4Obj_gt_02():
+    """Simple greater-than test - different network number"""
+    obj1 = IPv4Obj("1.1.1.0/24")
+    obj2 = IPv4Obj("1.1.0.0/24")
+    assert obj1 > obj2
+
+
+def testIPv4Obj_gt_03():
+    """Simple greater-than test - different prefixlen"""
+    obj1 = IPv4Obj("1.1.1.0/24")
+    obj2 = IPv4Obj("1.1.0.0/23")
+    assert obj1 > obj2
+
+
+def testIPv4Obj_lt_01():
+    """Simple less-than test - same network number"""
+    obj1 = IPv4Obj("1.1.1.1/24")
+    obj2 = IPv4Obj("1.1.1.0/24")
+    assert obj2 < obj1
+
+
+def testIPv4Obj_lt_02():
+    """Simple less-than test - different network number"""
+    obj1 = IPv4Obj("1.1.1.0/24")
+    obj2 = IPv4Obj("1.1.0.0/24")
+    assert obj2 < obj1
+
+
+def testIPv4Obj_lt_03():
+    """Simple less-than test - different prefixlen"""
+    obj1 = IPv4Obj("1.1.1.0/24")
+    obj2 = IPv4Obj("1.1.0.0/23")
+    assert obj2 < obj1
+
+
+def testIPv4Obj_contains_01():
+    """Test __contains__ method"""
+    obj1 = IPv4Obj("1.1.1.0/24")
+    obj2 = IPv4Obj("1.1.0.0/23")
+    assert obj1 in obj2
+
+
+def testIPv4Obj_contains_02():
+    """Test __contains__ method"""
+    obj1 = IPv4Obj("1.1.1.1/32")
+    obj2 = IPv4Obj("1.1.1.0/24")
+    assert obj1 in obj2
+
+
+def testIPv4Obj_contains_03():
+    """Test __contains__ method"""
+    obj1 = IPv4Obj("1.1.1.255/32")
+    obj2 = IPv4Obj("1.1.1.0/24")
+    assert obj1 in obj2
+
+
 def testIPv6Obj_recursive():
     """IPv6Obj() should be able to parse itself"""
     obj = IPv6Obj(IPv6Obj("fe80:a:b:c:d:e::1/64"))
     assert str(obj.ip_object) == "fe80:a:b:c:d:e:0:1"
     assert obj.prefixlen == 64
 
+def testIPv6Obj_neq_01():
+    """Simple in-equality test fail (ref - Github issue #180)"""
+    assert IPv6Obj("::1") != ""
+
+def testIPv6Obj_neq_02():
+    """Simple in-equality test"""
+    assert IPv6Obj("::1") != IPv6Obj("::2")
+
+def testIPv6Obj_eq_01():
+    """Simple equality test"""
+    assert IPv6Obj("::1") == IPv6Obj("::1")
 
 def test_dns_lookup():
     # Use VMWare's opencloud A-record to test...
@@ -354,5 +553,5 @@ def test_CiscoRange_compressed_str_01():
     assert CiscoRange("1,2, 3, 6, 7, 8, 9, 911").compressed_str == "1-3,6-9,911"
 
 
-def test_CiscoRange_contanis():
+def test_CiscoRange_contains():
     assert "Ethernet1/2" in CiscoRange("Ethernet1/1-20")
